*obtain path of the file
it works for windows operating system only, Mac and unix user please
hard code the path of the path macro variable;
%let path = %sysget(sas_execfilepath);
%let filename = %sysget(sas_execfilename);
%let path = %substr(&path, 1, %index(&path, \&filename));

*prepare a pseudo data set;
proc datasets lib = sashelp nolist;
	copy out = work;
	select cars;
quit;
data car1;
	set cars;
	call streaminit(12345);
	where drivetrain in ("Front" "Rear");
	if drivetrain = "Front" then do;
		gender = rand("uniform") > 0.5;
		if rand("uniform") > 0.9 then call missing(gender);
	end;
	else gender = rand("uniform") > 0.65;	
	temprandom = rand("uniform");	
	select;
		when(temprandom > 0.6) carmake = 1;
		when(temprandom > 0.3) carmake = 2;
		otherwise carmake = 0;
	end;
	if rand("uniform") > 0.95 then call missing(mpg_city);
	if rand("uniform") > 0.98 then call missing(mpg_highway);
run;

*compile the macros;
%include "&path.Table1Macro.sas";



*********************Example for Table1Macro*********************;

*1. simple example, with or without group variable;
*1.1 categorical variables only with or without group;
%Table1Macro(dsn = car1,
			 calist = type origin gender carmake, 
			 coplist = ,
			 cononplist= ,
			 group = drivetrain);
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist =,
			 cononplist=);
*1.2 parametric continuous variables only with or without group;
%Table1Macro(dsn = car1, 
			 calist = , 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= ,
	         group = drivetrain);
%Table1Macro(dsn = car1, 
			 calist = , 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist=);
*1.3 non-parametric continuous variables only with or without group;
%Table1Macro(dsn = car1, 
			 calist = , 
			 coplist = ,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain);
%Table1Macro(dsn = car1, 
			 calist = , 
			 coplist = ,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length);
*1.4 categorical and parametric continuous variable together with or without group;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= ,
	         group = drivetrain);
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= );
*1.5 categorical and non-parametric continuous variable together with or without group;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = ,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain);
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = ,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length);
*1.6 put all variables together with or without group;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain);
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length);



*2. change the order of the variable;
*default order is parametric continuous variable folled by non-parametric continuous variable, 
then followed by categorical variables;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake drivetrain, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type);

*3. use format to transfigure output;
*3.1 set up formats for variables;
proc format;
	value genderf			   0 = "Male"
							   1 = "Female";
	value carmakef			   0 = "Chrysler"
							   1 = "General Motor"
							   2 = "Ford";
	value $drivetrainf   "Front" = "Front Drive"
						 "Rear"  = "Rear Drive";
run;
*3.2 assign formats to variables including group variable;
data car1;
	set cars;
	call streaminit(12345);
	where drivetrain in ("Front" "Rear");
	if drivetrain = "Front" then do;
			gender = rand("uniform") > 0.5;
			if rand("uniform") > 0.9 then call missing(gender);
		end;
		else gender = rand("uniform") > 0.65;		
	select;
		when(rand("uniform")>0.6) carmake = 1;
		when(rand("uniform")>0.3) carmake = 2;
		otherwise carmake = 0;
	end;
	format gender genderf. carmake carmakef. drivetrain $drivetrainf.;
run;
proc datasets lib = work nolist;
	modify car1;
		format gender genderf. carmake carmakef. drivetrain $drivetrainf.;
quit;
*3.3 run the macro;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type);


*4. use label to transfigure output;
*4.1 assign label to categorical variables;
data car1;
	set cars;
	call streaminit(12345);
	where drivetrain in ("Front" "Rear");
	if drivetrain = "Front" then do;
			gender = rand("uniform") > 0.5;
			if rand("uniform") > 0.9 then call missing(gender);
		end;
		else gender = rand("uniform") > 0.65;		
	select;
		when(rand("uniform")>0.6) carmake = 1;
		when(rand("uniform")>0.3) carmake = 2;
		otherwise carmake = 0;
	end;
	format gender genderf. carmake carmakef. drivetrain $drivetrainf.;
	label carmake = "Manufacturer"
		  gender  = "Target Customer"
          drivetrain = "Drive Train Type";
run;
proc datasets lib = work nolist;
	modify car1;
		label 	carmake = "Manufacturer"
		  		gender  = "Target Customer"
				drivetrain = "Drive Train Type";
quit;
*4.2 run the macro;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type);

*5. include missing as an additional level;
*5.1 missing is the first level;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes, overall = yes);
*5.1 missing is the last level;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 missingtop = no,
			 overall = yes);

*6. fine adjust output with other parameters;
*6.1 change the reporting item for continuous variables
	 some typical values for the parameter
	 mean
	 median
	 range  - min to max
	 qrange - Q1 to Q3
	 IQR    - same as the qrange
	 CLM    - 95% confidence interval of mean
	 std	- standard deviation
	 stddev - same as std;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,

			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange

			 );
*6.2 change percentage type of the categorical variable;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,

			 percenttype = row

			 ); 
*6.3 change decimal, dec can be set as 0 or 1 or 2 for categorical variables, default is 2
	 and 0, 1, 2, 3, 4 or 5 for continuous variable, default is 1 and 0 for parametric and non-parametric 
	 continuous variable, respectively;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 percenttype = row,

			 cadec = 0,
			 copdec = 1,
			 cononpdec = 2

			 );

*6.4 change the proportion of cells with expected frequency less than 5, it can be set between 0 and 1;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 percenttype = row,
			 cadec = 0,
			 copdec = 2,
			 cononpdec = 2,

			 eratio = 0.5

			 );
*6.5 put variable in the exclude list avoiding Chi-square or Fisher Exact test;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 percenttype = row,
			 cadec = 0,
			 copdec = 2,
			 cononpdec = 2,
			 eratio = 0.5,

			 caexcludelist = gender carmake,
			 copexcludelist = mpg_city,
			 cononpexcludelist = mpg_highway

			 );
*6.6 only frequency table, no test, comparing notest and excludelist parameter;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 percenttype = row,
			 cadec = 0,
			 copdec = 2,
			 cononpdec = 2,
			 eratio = 0.5,
			 caexcludelist = gender carmake,
			 copexcludelist = mpg_city,
			 cononpexcludelist = mpg_highway,

			 notest = yes

			 );
*6.7 include overall columns in the final report;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 percenttype = row,
			 cadec = 0,
			 copdec = 2,
			 cononpdec = 2,
			 eratio = 0.5,
			 caexcludelist = gender carmake,
			 copexcludelist = mpg_city,
			 cononpexcludelist = mpg_highway,
			 notest = yes,

			 overall = yes

			 );
*6.8 change the padding character type;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 percenttype = row,
			 cadec = 0,
			 copdec = 2,
			 cononpdec = 2,
			 eratio = 0.5,
			 caexcludelist = gender carmake,
			 copexcludelist = mpg_city,
			 cononpexcludelist = mpg_highway,
			 notest = yes,
			 overall = yes,

			 paddingchar = 2

			 );
*6.9 change the style of variable line;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 cadec = 0,
			 copdec = 2,
			 cononpdec = 2,
			 eratio = 0.5,
			 caexcludelist = gender carmake,
			 copexcludelist = mpg_city,
			 cononpexcludelist = mpg_highway,
			 notest = yes,
			 overall = yes,
			 paddingchar = 1,

			 variableshading = no

			 );
*6.10 specify if report in SAS;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 percenttype = row,
			 cadec = 0,
			 copdec = 2,
			 cononpdec = 2,
			 eratio = 0.5,
			 caexcludelist = gender carmake,
			 copexcludelist = mpg_city,
			 cononpexcludelist = mpg_highway,
			 notest = yes,
			 overall = yes,
			 paddingchar = 1,
			 variableshading = no,

			 reportinSAS = yes,
			 creatertf = yno

			 );
*6.11 label variable using Fisher Exact test and non-equal variance T-test;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 percenttype = row,
			 cadec = 0,
			 copdec = 2,
			 cononpdec = 2,
			 eratio = 0.2,
			 caexcludelist = gender carmake,
			 copexcludelist = mpg_city,
			 cononpexcludelist = mpg_highway,

			 notest = no,

			 overall = yes,
			 paddingchar = 1,
			 variableshading = no,
			 reportinSAS = yes,
			 creatertf = yes,

			 labelvariable = yes

			 );
*6.12 change the name of output data set;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 percenttype = row,
			 cadec = 0,
			 copdec = 2,
			 cononpdec = 2,
			 eratio = 0.5,
			 caexcludelist = gender carmake,
			 copexcludelist = mpg_city,
			 cononpexcludelist = mpg_highway,
			 notest = yes,
			 overall = yes,
			 paddingchar = 2,
			 variableshading = no,
			 reportinSAS = yes,
			 creatertf = yes,
			 labelvariable = no,
			
			 outdsn = table1

			 );
*6.13 suppress warning message;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 percenttype = row,
			 cadec = 0,
			 copdec = 2,
			 cononpdec = 2,
			 eratio = 0.5,
			 caexcludelist = gender carmake,
			 copexcludelist = mpg_city,
			 cononpexcludelist = mpg_highway,
			 notest = yes,
			 overall = yes,
			 paddingchar = 2,
			 variableshading = no,
			 reportinSAS = yes,
			 creatertf = no,
			 labelvariable = no,
			 outdsn = table1,

			 suppresswarning = no

			 );
*6.14 specify name for output rtf file;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 percenttype = row,
			 cadec = 0,
			 copdec = 2,
			 cononpdec = 2,
			 eratio = 0.5,
			 caexcludelist = gender carmake,
			 copexcludelist = mpg_city,
			 cononpexcludelist = mpg_highway,
			 notest = yes,
			 overall = yes,
			 paddingchar = 2,
			 variableshading = no,
			 reportinSAS = yes,

			 creatertf = yes,

			 labelvariable = no,
			 outdsn = table1,
			 suppresswarning = yes,
			 
			 savefilename = summary

			 );
*6.15 change the order of two types of continuous variable;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 percenttype = row,
			 cadec = 0,
			 copdec = 2,
			 cononpdec = 2,
			 eratio = 0.5,
			 caexcludelist = gender carmake,
			 copexcludelist = mpg_city,
			 cononpexcludelist = mpg_highway,
			 notest = yes,
			 overall = yes,
			 paddingchar = 2,
			 variableshading = no,
			 reportinSAS = yes,
			 creatertf = yes,
			 labelvariable = no,
			 outdsn = table1,
			 suppresswarning = yes,			 
			 savefilename = summary,

			 continuousorder = 2

			 );
*6.16 not compact table;
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain,
			 outputorder = gender carmake mpg_city mpg_highway type,
			 caincludemissing = yes,
			 copincludemissing = yes,
			 cononpincludemissing = yes,
			 copmain = mean,
			 copsupplement = CLM,
			 cononpmain = median,
			 cononpsupplement = qrange,
			 percenttype = row,
			 cadec = 0,
			 copdec = 2,
			 cononpdec = 2,
			 eratio = 0.5,
			 caexcludelist = gender carmake,
			 copexcludelist = mpg_city,
			 cononpexcludelist = mpg_highway,
			 notest = yes,
			 overall = yes,
			 paddingchar = 2,
			 variableshading = no,
			 reportinSAS = yes,
			 creatertf = yes,
			 labelvariable = no,
			 outdsn = table2,
			 suppresswarning = yes,			 
			 savefilename = summary,
			 continuousorder = 2,

			 compacttable = no

			 );
*tips of using the macro;
*1. analyzing continuous variable with format;
proc format;
	value invoicef   low - <25000 = "Less than 25,000"
					25000 - high  = "At least 25,000";
run;
proc datasets lib = work nolist;
	modify car1;
		format invoice invoicef.;
quit;
data car1;
	set car1;
	if drivetrain = "Front" and rand("uniform") > 0.8 then call missing(invoice);
run;
%Table1Macro(dsn = car1, 
             calist = invoice, 
			 coplist = invoice, 
			 group = drivetrain,
			 caexcludelist = invoice);


*2. report the third statistics for continuous variable;
%Table1Macro(dsn = car1, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 group = drivetrain,
			 copmain = mean,
			 copsupplement = std,
			 cononpmain = range,
			 cononpsupplement = ,
			 copincludemissing = yes,
			 cononpexcludelist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 outputorder = mpg_highway mpg_city, pvaluetop = yes
			);



*example of program halted with Fisher Exast test;
data car1;
	set cars;
	call streaminit(12345);
/*	where drivetrain in ("Front" "Rear");*/
	if drivetrain = "Front" then do;
			gender = rand("uniform") > 0.5;
			if rand("uniform") > 0.9 then call missing(gender);
		end;
		else gender = rand("uniform") > 0.65;		
	select;
		when(rand("uniform")>0.6) carmake = 1;
		when(rand("uniform")>0.3) carmake = 2;
		otherwise carmake = 0;
	end;
	if type = "SUV" and rand("uniform")> 0.05 then call missing(type);
	if rand("uniform") > 0.95 then call missing(mpg_city);
	if rand("uniform") > 0.98 then call missing(mpg_highway);
run;


%include "&path.Table1Macro.sas";
%Table1Macro(dsn = car1, 
			 calist = type origin gender carmake drivetrain, 
			 coplist = msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
			 cononplist= msrp invoice enginesize cylinders horsepower mpg_city mpg_highway weight wheelbase length,
	         group = drivetrain, labelvariable = yes,
			 outputorder = gender carmake mpg_city mpg_highway type);
